@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::DynamicPrereqs; # git description: v0.028-4-g655ac72
+package Dist::Zilla::Plugin::DynamicPrereqs; # git description: v0.029-8-g78ff959
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Specify dynamic (user-side) prerequisites for your distribution
 # KEYWORDS: plugin distribution metadata MYMETA prerequisites Makefile.PL dynamic
 
-our $VERSION = '0.029';
+our $VERSION = '0.030';
 
 use Moose;
 with
@@ -66,6 +66,7 @@ has $_ => (
 ) foreach qw(include_subs conditions);
 
 # temporary workaround for broken Module::CoreList::is_core
+# (see https://rt.perl.org/rt3/Ticket/Display.html?id=128089)
 has '+include_dependencies' => (
     default => 0,
 ) if eval { Dist::Zilla::Role::ModuleIncluder->VERSION('0.005'); 1 };
@@ -239,18 +240,18 @@ sub _build__sub_definitions
 
 my %sub_prereqs = (
     can_cc => {
-        'Config' => '0',
+        'Config' => '0',                # core since perl 5.00307
     },
     can_run => {
-        'File::Spec' => '0',
-        'Config' => '0',
+        'File::Spec' => '0',            # core since perl 5.00405
+        'Config' => '0',                # core since perl 5.00307
     },
     parse_args => {
-        'Text::ParseWords' => '0',
+        'Text::ParseWords' => '0',      # core since perl 5.000
     },
     has_module => {
-        'Module::Metadata' => '0',
-        'CPAN::Meta::Requirements' => '2.120620',   # for add_string_requirement
+        'Module::Metadata' => '0',      # core since perl 5.013009
+        'CPAN::Meta::Requirements' => '2.120620',   # core since perl 5.015007
     },
 );
 
@@ -409,7 +410,7 @@ Dist::Zilla::Plugin::DynamicPrereqs - Specify dynamic (user-side) prerequisites
 
 =head1 VERSION
 
-version 0.029
+version 0.030
 
 =head1 SYNOPSIS
 
@@ -570,7 +571,7 @@ C<parse_args()> - returns the hashref of options that were passed as arguments t
 
 =item *
 
-C<can_xs()> - XS capability testing via L<ExtUtils::HasCompiler> (don't forget to also check C<want_pp>!)
+C<can_xs()> - XS capability testing via L<ExtUtils::HasCompiler> (don't forget to also check C<want_pp>!) Available in this form since 0.029.
 
 =item *
 
@@ -584,9 +585,11 @@ C<can_run()> - check if we can run some command
 
 C<can_use($module [, $version ])> - checks if a module (optionally, at a specified version) can be loaded. (If you don't want to load the module, you should use C<< has_module >>, see below.)
 
+=for stopwords backcompat
+
 =item *
 
-C<has_module($module [, $version_or_range ])> - checks if a module (optionally, at a specified version or matching a L<version range|CPAN::Meta::Spec/version_ranges>) is available in C<%INC>. Does not load the module, so is safe to use with modules that have side effects when loaded.  When passed a second argument, returns true or false; otherwise, returns undef or the module's C<$VERSION>. (Current API available since version 0.015.)
+C<has_module($module [, $version_or_range ])> - checks if a module (optionally, at a specified version or matching a L<version range|CPAN::Meta::Spec/version_ranges>) is available in C<%INC>. Does not load the module, so is safe to use with modules that have side effects when loaded.  When passed a second argument, returns true or false; otherwise, returns undef or the module's C<$VERSION>. Note that for extremely simple usecases (module has no side effects when loading, and no explicit version is needed), it can be simpler and more backcompat-friendly to simply do: C<< eval { require Foo::Bar } >>. (Current API available since version 0.015.)
 
 =item *
 
